@@ -2,7 +2,7 @@ from django.contrib import admin
 from glinks.models import Blueprint, Glink, ImpressionTracking, ClickTracking
 
 class GlinkAdmin(admin.ModelAdmin):
-	fields = ['blueprint', 'name', 'weight', 'URL', 'image', 'impressions', 'clicks', 'mostClicksLocation', 'mostViewedLocation']
+	fields = ['blueprint', 'name', 'isActive', 'weight', 'URL', 'image', 'start_date', 'expiry_date', 'impressions', 'clicks', 'mostClicksLocation', 'mostViewedLocation']
 
 	def get_readonly_fields(self, request, obj=None):
 		return ['impressions', 'clicks', 'mostClicksLocation', 'mostViewedLocation']
